.. timeboard documentation master file, created by
   sphinx-quickstart on Thu Jan 18 18:48:32 2018.

Welcome to timeboard's documentation!
======================================

:py:mod:`timeboard` performs calendar calculations over business schedules such as business days or work shifts.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   about
   installation
   quick_start
   data_model
   making_a_timeboard
   using_preconfigured
   doing_calculations
   use_cases.ipynb
   release_notes

* :ref:`genindex`

.. * :ref:`modindex`
.. * :ref:`search`

Downloads:

* :download:`jupyter notebook <use_cases.ipynb>` with common use cases

Links:

* Github: https://github.com/mmamaev/timeboard
* PyPI: https://pypi.python.org/pypi/timeboard
* Documentation (this page): https://timeboard.readthedocs.io/
